@@ -6,7 +6,7 @@
 # raise a `RecursionError`.
 # In order to avoid this, import only the API that you directly need like:
 #
-#   from cvg_sdk.api.recording_api import RecordingApi
+#   from cvg_sdk.api.health_api import HealthApi
 #
 # or import this package, but before doing it, use:
 #
@@ -14,4 +14,4 @@
 #   sys.setrecursionlimit(n)
 
 # Import APIs into API package:
-from cvg_sdk.api.recording_api import RecordingApi
+from cvg_sdk.api.health_api import HealthApi
